# CHANGELOG

## Unreleased

## 0.9.0 (2025-02-25)

### Changed

- ragbits-core updated to version v0.9.0

## 0.8.0 (2025-01-29)

### Changed

- ragbits-core updated to version v0.8.0

## 0.7.0 (2025-01-21)

### Changed

- ragbits-core updated to version v0.7.0

## 0.6.0 (2024-12-27)

### Changed

- ragbits-core updated to version v0.6.0

## 0.5.1 (2024-12-09)

### Changed

- ragbits-core updated to version v0.5.1

## 0.5.0 (2024-12-05)

### Changed

- ragbits-core updated to version v0.5.0

## 0.4.0 (2024-11-27)

### Changed

- ragbits-core updated to version v0.4.0

## 0.3.0 (2024-11-06)

### Added

- Initial release of the package (#169).
- First guardrail with OpenAI Moderation.

